You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@activemq.apache.org by cl...@apache.org on 2015/04/28 18:02:44 UTC

[39/57] [abbrv] [partial] activemq-6 git commit: ACTIVEMQ6-1 Artemis rename

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-maven-plugin/pom.xml
----------------------------------------------------------------------
diff --git a/artemis-maven-plugin/pom.xml b/artemis-maven-plugin/pom.xml
index f50de06..f97a4b9 100644
--- a/artemis-maven-plugin/pom.xml
+++ b/artemis-maven-plugin/pom.xml
@@ -19,11 +19,11 @@
 
    <parent>
       <groupId>org.apache.activemq</groupId>
-      <artifactId>activemq-pom</artifactId>
-      <version>10.0.0-SNAPSHOT</version>
+      <artifactId>artemis-pom</artifactId>
+      <version>1.0.0-SNAPSHOT</version>
    </parent>
 
-   <artifactId>activemq-maven-plugin</artifactId>
+   <artifactId>artemis-maven-plugin</artifactId>
    <packaging>maven-plugin</packaging>
    <name>ActiveMQ Artemis Maven Plugin</name>
 
@@ -44,12 +44,12 @@
       </dependency>
       <dependency>
          <groupId>org.apache.activemq</groupId>
-         <artifactId>activemq-server</artifactId>
+         <artifactId>artemis-server</artifactId>
          <version>${project.version}</version>
       </dependency>
       <dependency>
          <groupId>org.apache.activemq</groupId>
-         <artifactId>activemq-jms-server</artifactId>
+         <artifactId>artemis-jms-server</artifactId>
          <version>${project.version}</version>
       </dependency>
       <dependency>

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/ActiveMQClient.java
----------------------------------------------------------------------
diff --git a/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/ActiveMQClient.java b/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/ActiveMQClient.java
index 120bf21..a59546b 100644
--- a/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/ActiveMQClient.java
+++ b/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/ActiveMQClient.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.maven;
+package org.apache.activemq.artemis.maven;
 
 public interface ActiveMQClient
 {

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/ActiveMQClientPlugin.java
----------------------------------------------------------------------
diff --git a/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/ActiveMQClientPlugin.java b/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/ActiveMQClientPlugin.java
index 6dfd9f0..d9b7787 100644
--- a/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/ActiveMQClientPlugin.java
+++ b/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/ActiveMQClientPlugin.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.maven;
+package org.apache.activemq.artemis.maven;
 
 import java.lang.reflect.Method;
 import java.util.Properties;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/ActiveMQStartPlugin.java
----------------------------------------------------------------------
diff --git a/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/ActiveMQStartPlugin.java b/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/ActiveMQStartPlugin.java
index 2d111d3..f5b4aa2 100644
--- a/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/ActiveMQStartPlugin.java
+++ b/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/ActiveMQStartPlugin.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.maven;
+package org.apache.activemq.artemis.maven;
 
 import javax.management.MBeanServer;
 import javax.management.ObjectName;
@@ -23,10 +23,10 @@ import java.lang.management.ManagementFactory;
 import java.util.Arrays;
 import java.util.Properties;
 
-import org.apache.activemq.server.ActiveMQBootstrap;
-import org.apache.activemq.server.SpawnedActiveMQBootstrap;
-import org.apache.activemq.server.SpawnedVMSupport;
-import org.apache.activemq.spi.core.security.ActiveMQSecurityManager;
+import org.apache.activemq.artemis.server.ActiveMQBootstrap;
+import org.apache.activemq.artemis.server.SpawnedActiveMQBootstrap;
+import org.apache.activemq.artemis.server.SpawnedVMSupport;
+import org.apache.activemq.artemis.spi.core.security.ActiveMQSecurityManager;
 import org.apache.maven.plugin.AbstractMojo;
 import org.apache.maven.plugin.MojoExecutionException;
 import org.apache.maven.plugin.MojoFailureException;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/ActiveMQStopPlugin.java
----------------------------------------------------------------------
diff --git a/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/ActiveMQStopPlugin.java b/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/ActiveMQStopPlugin.java
index 99d1708..51a74a7 100644
--- a/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/ActiveMQStopPlugin.java
+++ b/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/ActiveMQStopPlugin.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.maven;
+package org.apache.activemq.artemis.maven;
 
 import org.apache.maven.plugin.AbstractMojo;
 import org.apache.maven.plugin.MojoExecutionException;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/InVMNodeManagerServer.java
----------------------------------------------------------------------
diff --git a/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/InVMNodeManagerServer.java b/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/InVMNodeManagerServer.java
index 97d3f37..20c4d81 100644
--- a/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/InVMNodeManagerServer.java
+++ b/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/InVMNodeManagerServer.java
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.maven;
+package org.apache.activemq.artemis.maven;
 
 import javax.management.MBeanServer;
 
-import org.apache.activemq.core.config.Configuration;
-import org.apache.activemq.core.server.NodeManager;
-import org.apache.activemq.core.server.impl.ActiveMQServerImpl;
-import org.apache.activemq.spi.core.security.ActiveMQSecurityManager;
+import org.apache.activemq.artemis.core.config.Configuration;
+import org.apache.activemq.artemis.core.server.NodeManager;
+import org.apache.activemq.artemis.core.server.impl.ActiveMQServerImpl;
+import org.apache.activemq.artemis.spi.core.security.ActiveMQSecurityManager;
 
 public final class InVMNodeManagerServer extends ActiveMQServerImpl
 {

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/PluginUtil.java
----------------------------------------------------------------------
diff --git a/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/PluginUtil.java b/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/PluginUtil.java
index a066f4f..100423f 100644
--- a/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/PluginUtil.java
+++ b/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/PluginUtil.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.maven;
+package org.apache.activemq.artemis.maven;
 
 import javax.management.MBeanServerConnection;
 import javax.management.MBeanServerInvocationHandler;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/TestClusterManager.java
----------------------------------------------------------------------
diff --git a/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/TestClusterManager.java b/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/TestClusterManager.java
index b03fa58..c86f1c0 100644
--- a/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/TestClusterManager.java
+++ b/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/TestClusterManager.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.maven;
+package org.apache.activemq.artemis.maven;
 
 import java.io.IOException;
 import java.util.ArrayList;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/TestClusterManagerMBean.java
----------------------------------------------------------------------
diff --git a/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/TestClusterManagerMBean.java b/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/TestClusterManagerMBean.java
index 001e7a8..d38163c 100644
--- a/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/TestClusterManagerMBean.java
+++ b/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/TestClusterManagerMBean.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.maven;
+package org.apache.activemq.artemis.maven;
 
 import java.io.IOException;
 

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/TestNode.java
----------------------------------------------------------------------
diff --git a/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/TestNode.java b/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/TestNode.java
index ba31c50..73c1950 100644
--- a/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/TestNode.java
+++ b/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/maven/TestNode.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.maven;
+package org.apache.activemq.artemis.maven;
 
 import java.io.File;
 import java.io.IOException;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/server/ActiveMQBootstrap.java
----------------------------------------------------------------------
diff --git a/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/server/ActiveMQBootstrap.java b/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/server/ActiveMQBootstrap.java
index 2875afe..c872f51 100644
--- a/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/server/ActiveMQBootstrap.java
+++ b/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/server/ActiveMQBootstrap.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.server;
+package org.apache.activemq.artemis.server;
 
 import java.io.File;
 import java.lang.management.ManagementFactory;
@@ -23,26 +23,26 @@ import java.util.Map;
 import java.util.Timer;
 import java.util.TimerTask;
 
-import org.apache.activemq.core.config.Configuration;
-import org.apache.activemq.core.config.FileDeploymentManager;
-import org.apache.activemq.core.config.HAPolicyConfiguration;
-import org.apache.activemq.core.config.impl.ConfigurationImpl;
-import org.apache.activemq.core.config.impl.FileConfiguration;
-import org.apache.activemq.core.config.impl.FileSecurityConfiguration;
-import org.apache.activemq.core.config.impl.SecurityConfiguration;
-import org.apache.activemq.core.server.ActiveMQServer;
-import org.apache.activemq.core.server.JournalType;
-import org.apache.activemq.core.server.NodeManager;
-import org.apache.activemq.core.server.impl.ActiveMQServerImpl;
-import org.apache.activemq.core.server.impl.InVMNodeManager;
-import org.apache.activemq.jms.server.JMSServerManager;
-import org.apache.activemq.jms.server.config.JMSConfiguration;
-import org.apache.activemq.jms.server.config.impl.JMSConfigurationImpl;
-import org.apache.activemq.jms.server.config.impl.FileJMSConfiguration;
-import org.apache.activemq.jms.server.impl.JMSServerManagerImpl;
-import org.apache.activemq.maven.InVMNodeManagerServer;
-import org.apache.activemq.spi.core.security.ActiveMQSecurityManager;
-import org.apache.activemq.spi.core.security.ActiveMQSecurityManagerImpl;
+import org.apache.activemq.artemis.core.config.Configuration;
+import org.apache.activemq.artemis.core.config.FileDeploymentManager;
+import org.apache.activemq.artemis.core.config.HAPolicyConfiguration;
+import org.apache.activemq.artemis.core.config.impl.ConfigurationImpl;
+import org.apache.activemq.artemis.core.config.impl.FileConfiguration;
+import org.apache.activemq.artemis.core.config.impl.FileSecurityConfiguration;
+import org.apache.activemq.artemis.core.config.impl.SecurityConfiguration;
+import org.apache.activemq.artemis.core.server.ActiveMQServer;
+import org.apache.activemq.artemis.core.server.JournalType;
+import org.apache.activemq.artemis.core.server.NodeManager;
+import org.apache.activemq.artemis.core.server.impl.ActiveMQServerImpl;
+import org.apache.activemq.artemis.core.server.impl.InVMNodeManager;
+import org.apache.activemq.artemis.jms.server.JMSServerManager;
+import org.apache.activemq.artemis.jms.server.config.JMSConfiguration;
+import org.apache.activemq.artemis.jms.server.config.impl.JMSConfigurationImpl;
+import org.apache.activemq.artemis.jms.server.config.impl.FileJMSConfiguration;
+import org.apache.activemq.artemis.jms.server.impl.JMSServerManagerImpl;
+import org.apache.activemq.artemis.maven.InVMNodeManagerServer;
+import org.apache.activemq.artemis.spi.core.security.ActiveMQSecurityManager;
+import org.apache.activemq.artemis.spi.core.security.ActiveMQSecurityManagerImpl;
 
 /**
  * This will bootstrap the HornetQ Server and also the naming server if required

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/server/SpawnedActiveMQBootstrap.java
----------------------------------------------------------------------
diff --git a/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/server/SpawnedActiveMQBootstrap.java b/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/server/SpawnedActiveMQBootstrap.java
index b44e5ed..6c23032 100644
--- a/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/server/SpawnedActiveMQBootstrap.java
+++ b/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/server/SpawnedActiveMQBootstrap.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.server;
+package org.apache.activemq.artemis.server;
 
 /**
  *         This class will be spawned in a new vm and will call the bootstrap

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/server/SpawnedVMSupport.java
----------------------------------------------------------------------
diff --git a/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/server/SpawnedVMSupport.java b/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/server/SpawnedVMSupport.java
index 9f72bf8..4cd0691 100644
--- a/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/server/SpawnedVMSupport.java
+++ b/artemis-maven-plugin/src/main/java/org/apache/activemq/artemis/server/SpawnedVMSupport.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.server;
+package org.apache.activemq.artemis.server;
 
 import java.io.BufferedReader;
 import java.io.File;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-native/pom.xml
----------------------------------------------------------------------
diff --git a/artemis-native/pom.xml b/artemis-native/pom.xml
index e690c5b..0e976a5 100644
--- a/artemis-native/pom.xml
+++ b/artemis-native/pom.xml
@@ -20,16 +20,16 @@
 
    <parent>
       <groupId>org.apache.activemq</groupId>
-      <artifactId>activemq-pom</artifactId>
-      <version>10.0.0-SNAPSHOT</version>
+      <artifactId>artemis-pom</artifactId>
+      <version>1.0.0-SNAPSHOT</version>
    </parent>
 
-   <artifactId>activemq-native</artifactId>
+   <artifactId>artemis-native</artifactId>
    <packaging>${native-package-type}</packaging>
    <dependencies>
       <dependency>
          <groupId>org.apache.activemq</groupId>
-         <artifactId>activemq-commons</artifactId>
+         <artifactId>artemis-commons</artifactId>
          <version>${project.version}</version>
       </dependency>
    </dependencies>
@@ -123,7 +123,7 @@
                      <libraries>
                         <library>
                            <type>jni</type>
-                           <narSystemPackage>org.apache.activemq.core.libaio</narSystemPackage>
+                           <narSystemPackage>org.apache.activemq.artemis.core.libaio</narSystemPackage>
                         </library>
                      </libraries>
                   </configuration>

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-native/src/main/c/JNI_AsynchronousFileImpl.cpp
----------------------------------------------------------------------
diff --git a/artemis-native/src/main/c/JNI_AsynchronousFileImpl.cpp b/artemis-native/src/main/c/JNI_AsynchronousFileImpl.cpp
index 2db78b2..259f9a6 100644
--- a/artemis-native/src/main/c/JNI_AsynchronousFileImpl.cpp
+++ b/artemis-native/src/main/c/JNI_AsynchronousFileImpl.cpp
@@ -41,14 +41,14 @@ struct timespec nanoTime;
 inline AIOController * getController(JNIEnv *env, jobject & controllerAddress)
 {
      return (AIOController *) env->GetDirectBufferAddress(controllerAddress);
-} 
+}
 
 /* Inaccessible static: log */
 /* Inaccessible static: totalMaxIO */
 /* Inaccessible static: loaded */
 /* Inaccessible static: EXPECTED_NATIVE_VERSION */
 /*
- * Class:     org.apache.activemq6_core_asyncio_impl_AsynchronousFileImpl
+ * Class:     org.apache.activemq.artemis_core_asyncio_impl_AsynchronousFileImpl
  * Method:    openFile
  * Signature: (Ljava/lang/String;)I
  */
@@ -61,7 +61,7 @@ JNIEXPORT jint JNICALL Java_org_apache_activemq_core_libaio_Native_openFile
 }
 
 /*
- * Class:     org.apache.activemq6_core_asyncio_impl_AsynchronousFileImpl
+ * Class:     org.apache.activemq.artemis_core_asyncio_impl_AsynchronousFileImpl
  * Method:    closeFile
  * Signature: (I)V
  */
@@ -72,7 +72,7 @@ JNIEXPORT void JNICALL Java_org_apache_activemq_core_libaio_Native_closeFile
 }
 
 /*
- * Class:     org.apache.activemq6_core_asyncio_impl_AsynchronousFileImpl
+ * Class:     org.apache.activemq.artemis_core_asyncio_impl_AsynchronousFileImpl
  * Method:    flock
  * Signature: (I)Z
  */

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-native/src/main/c/Version.h
----------------------------------------------------------------------
diff --git a/artemis-native/src/main/c/Version.h b/artemis-native/src/main/c/Version.h
index 6e02098..5b521b3 100644
--- a/artemis-native/src/main/c/Version.h
+++ b/artemis-native/src/main/c/Version.h
@@ -17,7 +17,7 @@
 
 #ifndef _VERSION_NATIVE_AIO
 
-// This definition needs to match org.apache.activemq.core.asyncio.impl.AsynchronousFileImpl.EXPECTED_NATIVE_VERSION
+// This definition needs to match org.apache.activemq.artemis.core.asyncio.impl.AsynchronousFileImpl.EXPECTED_NATIVE_VERSION
 // Or else the native module won't be loaded because of version mismatches
 #define _VERSION_NATIVE_AIO 52
 #endif

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-native/src/main/java/org/apache/activemq/artemis/core/libaio/Native.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-amqp-protocol/pom.xml b/artemis-protocols/artemis-amqp-protocol/pom.xml
index 66c542b..2b48875 100644
--- a/artemis-protocols/artemis-amqp-protocol/pom.xml
+++ b/artemis-protocols/artemis-amqp-protocol/pom.xml
@@ -16,14 +16,13 @@
 -->
 <project xmlns="http://maven.apache.org/POM/4.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/xsd/maven-4.0.0.xsd">
    <parent>
-      <artifactId>activemq-protocols</artifactId>
+      <artifactId>artemis-protocols</artifactId>
       <groupId>org.apache.activemq</groupId>
-      <version>10.0.0-SNAPSHOT</version>
+      <version>1.0.0-SNAPSHOT</version>
    </parent>
    <modelVersion>4.0.0</modelVersion>
 
-   <artifactId>activemq-amqp-protocol</artifactId>
-   <name>ActiveMQ Artemis AMQP Protocol</name>
+   <artifactId>artemis-amqp-protocol</artifactId>
 
    <properties>
       <activemq.basedir>${project.basedir}/../..</activemq.basedir>
@@ -33,12 +32,12 @@
       <!-- JMS Client because of some Convertions that are done -->
       <dependency>
          <groupId>org.apache.activemq</groupId>
-         <artifactId>activemq-jms-client</artifactId>
+         <artifactId>artemis-jms-client</artifactId>
          <version>${project.version}</version>
       </dependency>
       <dependency>
          <groupId>org.apache.activemq</groupId>
-         <artifactId>activemq-core-client</artifactId>
+         <artifactId>artemis-core-client</artifactId>
          <version>${project.version}</version>
       </dependency>
       <dependency>
@@ -61,7 +60,7 @@
       <!-- this is for the log assertion -->
       <dependency>
          <groupId>org.apache.activemq</groupId>
-         <artifactId>activemq-commons</artifactId>
+         <artifactId>artemis-commons</artifactId>
          <version>${project.version}</version>
       </dependency>
 
@@ -71,12 +70,12 @@
       </dependency>
       <dependency>
          <groupId>org.apache.activemq</groupId>
-         <artifactId>activemq-server</artifactId>
+         <artifactId>artemis-server</artifactId>
          <version>${project.version}</version>
       </dependency>
       <dependency>
          <groupId>org.apache.activemq</groupId>
-         <artifactId>activemq-proton-plug</artifactId>
+         <artifactId>artemis-proton-plug</artifactId>
          <version>${project.version}</version>
       </dependency>
       <dependency>

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/ActiveMQProtonRemotingConnection.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/ActiveMQProtonRemotingConnection.java b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/ActiveMQProtonRemotingConnection.java
index 1dfe055..24a28a1 100644
--- a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/ActiveMQProtonRemotingConnection.java
+++ b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/ActiveMQProtonRemotingConnection.java
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.core.protocol.proton;
+package org.apache.activemq.artemis.core.protocol.proton;
 
 import java.util.concurrent.Executor;
 
-import org.apache.activemq.api.core.ActiveMQBuffer;
-import org.apache.activemq.api.core.ActiveMQException;
-import org.apache.activemq.core.client.ActiveMQClientLogger;
-import org.apache.activemq.spi.core.protocol.AbstractRemotingConnection;
-import org.apache.activemq.spi.core.remoting.Connection;
+import org.apache.activemq.artemis.api.core.ActiveMQBuffer;
+import org.apache.activemq.artemis.api.core.ActiveMQException;
+import org.apache.activemq.artemis.core.client.ActiveMQClientLogger;
+import org.apache.activemq.artemis.spi.core.protocol.AbstractRemotingConnection;
+import org.apache.activemq.artemis.spi.core.remoting.Connection;
 import org.proton.plug.AMQPConnectionContext;
 
 /**

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/ProtonProtocolManager.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/ProtonProtocolManager.java b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/ProtonProtocolManager.java
index dd88cab..ef40eeb 100644
--- a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/ProtonProtocolManager.java
+++ b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/ProtonProtocolManager.java
@@ -14,29 +14,29 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.core.protocol.proton;
+package org.apache.activemq.artemis.core.protocol.proton;
 
 import java.util.List;
 import java.util.concurrent.Executor;
 
 import io.netty.channel.ChannelPipeline;
-import org.apache.activemq.api.core.ActiveMQBuffer;
-import org.apache.activemq.api.core.BaseInterceptor;
-import org.apache.activemq.api.core.Interceptor;
-import org.apache.activemq.api.core.client.ActiveMQClient;
-import org.apache.activemq.core.protocol.proton.converter.ProtonMessageConverter;
-import org.apache.activemq.core.protocol.proton.plug.ActiveMQProtonConnectionCallback;
-import org.apache.activemq.core.remoting.impl.netty.NettyServerConnection;
-import org.apache.activemq.core.server.ActiveMQServer;
-import org.apache.activemq.core.server.management.Notification;
-import org.apache.activemq.core.server.management.NotificationListener;
-import org.apache.activemq.spi.core.protocol.ConnectionEntry;
-import org.apache.activemq.spi.core.protocol.MessageConverter;
-import org.apache.activemq.spi.core.protocol.ProtocolManager;
-import org.apache.activemq.spi.core.protocol.ProtocolManagerFactory;
-import org.apache.activemq.spi.core.protocol.RemotingConnection;
-import org.apache.activemq.spi.core.remoting.Acceptor;
-import org.apache.activemq.spi.core.remoting.Connection;
+import org.apache.activemq.artemis.api.core.ActiveMQBuffer;
+import org.apache.activemq.artemis.api.core.BaseInterceptor;
+import org.apache.activemq.artemis.api.core.Interceptor;
+import org.apache.activemq.artemis.api.core.client.ActiveMQClient;
+import org.apache.activemq.artemis.core.protocol.proton.converter.ProtonMessageConverter;
+import org.apache.activemq.artemis.core.protocol.proton.plug.ActiveMQProtonConnectionCallback;
+import org.apache.activemq.artemis.core.remoting.impl.netty.NettyServerConnection;
+import org.apache.activemq.artemis.core.server.ActiveMQServer;
+import org.apache.activemq.artemis.core.server.management.Notification;
+import org.apache.activemq.artemis.core.server.management.NotificationListener;
+import org.apache.activemq.artemis.spi.core.protocol.ConnectionEntry;
+import org.apache.activemq.artemis.spi.core.protocol.MessageConverter;
+import org.apache.activemq.artemis.spi.core.protocol.ProtocolManager;
+import org.apache.activemq.artemis.spi.core.protocol.ProtocolManagerFactory;
+import org.apache.activemq.artemis.spi.core.protocol.RemotingConnection;
+import org.apache.activemq.artemis.spi.core.remoting.Acceptor;
+import org.apache.activemq.artemis.spi.core.remoting.Connection;
 import org.proton.plug.AMQPServerConnectionContext;
 import org.proton.plug.context.server.ProtonServerConnectionContextFactory;
 

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/ProtonProtocolManagerFactory.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/ProtonProtocolManagerFactory.java b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/ProtonProtocolManagerFactory.java
index 6fe2576..541a4b4 100644
--- a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/ProtonProtocolManagerFactory.java
+++ b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/ProtonProtocolManagerFactory.java
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.core.protocol.proton;
+package org.apache.activemq.artemis.core.protocol.proton;
 
-import org.apache.activemq.api.core.BaseInterceptor;
-import org.apache.activemq.api.core.Interceptor;
-import org.apache.activemq.core.server.ActiveMQServer;
-import org.apache.activemq.spi.core.protocol.AbstractProtocolManagerFactory;
-import org.apache.activemq.spi.core.protocol.ProtocolManager;
+import org.apache.activemq.artemis.api.core.BaseInterceptor;
+import org.apache.activemq.artemis.api.core.Interceptor;
+import org.apache.activemq.artemis.core.server.ActiveMQServer;
+import org.apache.activemq.artemis.spi.core.protocol.AbstractProtocolManagerFactory;
+import org.apache.activemq.artemis.spi.core.protocol.ProtocolManager;
 
 import java.util.Collections;
 import java.util.List;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/ActiveMQJMSVendor.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/ActiveMQJMSVendor.java b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/ActiveMQJMSVendor.java
index e675b98..683641f 100644
--- a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/ActiveMQJMSVendor.java
+++ b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/ActiveMQJMSVendor.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.core.protocol.proton.converter;
+package org.apache.activemq.artemis.core.protocol.proton.converter;
 
 import javax.jms.BytesMessage;
 import javax.jms.Destination;
@@ -25,15 +25,15 @@ import javax.jms.StreamMessage;
 import javax.jms.TextMessage;
 
 import org.apache.qpid.proton.jms.JMSVendor;
-import org.apache.activemq.core.buffers.impl.ResetLimitWrappedActiveMQBuffer;
-import org.apache.activemq.core.protocol.proton.converter.jms.ServerJMSBytesMessage;
-import org.apache.activemq.core.protocol.proton.converter.jms.ServerJMSMapMessage;
-import org.apache.activemq.core.protocol.proton.converter.jms.ServerJMSMessage;
-import org.apache.activemq.core.protocol.proton.converter.jms.ServerJMSStreamMessage;
-import org.apache.activemq.core.protocol.proton.converter.jms.ServerJMSTextMessage;
-import org.apache.activemq.core.server.ServerMessage;
-import org.apache.activemq.core.server.impl.ServerMessageImpl;
-import org.apache.activemq.utils.IDGenerator;
+import org.apache.activemq.artemis.core.buffers.impl.ResetLimitWrappedActiveMQBuffer;
+import org.apache.activemq.artemis.core.protocol.proton.converter.jms.ServerJMSBytesMessage;
+import org.apache.activemq.artemis.core.protocol.proton.converter.jms.ServerJMSMapMessage;
+import org.apache.activemq.artemis.core.protocol.proton.converter.jms.ServerJMSMessage;
+import org.apache.activemq.artemis.core.protocol.proton.converter.jms.ServerJMSStreamMessage;
+import org.apache.activemq.artemis.core.protocol.proton.converter.jms.ServerJMSTextMessage;
+import org.apache.activemq.artemis.core.server.ServerMessage;
+import org.apache.activemq.artemis.core.server.impl.ServerMessageImpl;
+import org.apache.activemq.artemis.utils.IDGenerator;
 
 public class ActiveMQJMSVendor extends JMSVendor
 {
@@ -48,25 +48,25 @@ public class ActiveMQJMSVendor extends JMSVendor
    @Override
    public BytesMessage createBytesMessage()
    {
-      return new ServerJMSBytesMessage(newMessage(org.apache.activemq.api.core.Message.BYTES_TYPE), 0);
+      return new ServerJMSBytesMessage(newMessage(org.apache.activemq.artemis.api.core.Message.BYTES_TYPE), 0);
    }
 
    @Override
    public StreamMessage createStreamMessage()
    {
-      return new ServerJMSStreamMessage(newMessage(org.apache.activemq.api.core.Message.STREAM_TYPE), 0);
+      return new ServerJMSStreamMessage(newMessage(org.apache.activemq.artemis.api.core.Message.STREAM_TYPE), 0);
    }
 
    @Override
    public Message createMessage()
    {
-      return new ServerJMSMessage(newMessage(org.apache.activemq.api.core.Message.DEFAULT_TYPE), 0 );
+      return new ServerJMSMessage(newMessage(org.apache.activemq.artemis.api.core.Message.DEFAULT_TYPE), 0 );
    }
 
    @Override
    public TextMessage createTextMessage()
    {
-      return new ServerJMSTextMessage(newMessage(org.apache.activemq.api.core.Message.TEXT_TYPE), 0);
+      return new ServerJMSTextMessage(newMessage(org.apache.activemq.artemis.api.core.Message.TEXT_TYPE), 0);
    }
 
    @Override
@@ -78,7 +78,7 @@ public class ActiveMQJMSVendor extends JMSVendor
    @Override
    public MapMessage createMapMessage()
    {
-      return new ServerJMSMapMessage(newMessage(org.apache.activemq.api.core.Message.MAP_TYPE), 0);
+      return new ServerJMSMapMessage(newMessage(org.apache.activemq.artemis.api.core.Message.MAP_TYPE), 0);
    }
 
    @Override
@@ -121,13 +121,13 @@ public class ActiveMQJMSVendor extends JMSVendor
    {
       switch (messageType)
       {
-         case org.apache.activemq.api.core.Message.STREAM_TYPE:
+         case org.apache.activemq.artemis.api.core.Message.STREAM_TYPE:
             return new ServerJMSStreamMessage(wrapped, deliveryCount);
-         case org.apache.activemq.api.core.Message.BYTES_TYPE:
+         case org.apache.activemq.artemis.api.core.Message.BYTES_TYPE:
             return new ServerJMSBytesMessage(wrapped, deliveryCount);
-         case org.apache.activemq.api.core.Message.MAP_TYPE:
+         case org.apache.activemq.artemis.api.core.Message.MAP_TYPE:
             return new ServerJMSMapMessage(wrapped, deliveryCount);
-         case org.apache.activemq.api.core.Message.TEXT_TYPE:
+         case org.apache.activemq.artemis.api.core.Message.TEXT_TYPE:
             return new ServerJMSTextMessage(wrapped, deliveryCount);
          default:
             return new ServerJMSMessage(wrapped, deliveryCount);

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/ProtonMessageConverter.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/ProtonMessageConverter.java b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/ProtonMessageConverter.java
index 2f65675..81a7469 100644
--- a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/ProtonMessageConverter.java
+++ b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/ProtonMessageConverter.java
@@ -14,16 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.core.protocol.proton.converter;
+package org.apache.activemq.artemis.core.protocol.proton.converter;
 
 import org.apache.qpid.proton.jms.EncodedMessage;
 import org.apache.qpid.proton.jms.InboundTransformer;
 import org.apache.qpid.proton.jms.JMSMappingInboundTransformer;
 import org.apache.qpid.proton.jms.JMSMappingOutboundTransformer;
-import org.apache.activemq.core.protocol.proton.converter.jms.ServerJMSMessage;
-import org.apache.activemq.core.server.ServerMessage;
-import org.apache.activemq.spi.core.protocol.MessageConverter;
-import org.apache.activemq.utils.IDGenerator;
+import org.apache.activemq.artemis.core.protocol.proton.converter.jms.ServerJMSMessage;
+import org.apache.activemq.artemis.core.server.ServerMessage;
+import org.apache.activemq.artemis.spi.core.protocol.MessageConverter;
+import org.apache.activemq.artemis.utils.IDGenerator;
 
 public class ProtonMessageConverter implements MessageConverter
 {

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSBytesMessage.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSBytesMessage.java b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSBytesMessage.java
index b60191c..0854671 100644
--- a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSBytesMessage.java
+++ b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSBytesMessage.java
@@ -14,38 +14,38 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.core.protocol.proton.converter.jms;
+package org.apache.activemq.artemis.core.protocol.proton.converter.jms;
 
 import javax.jms.BytesMessage;
 import javax.jms.JMSException;
 
-import org.apache.activemq.core.message.impl.MessageImpl;
-import org.apache.activemq.core.message.impl.MessageInternal;
-
-import static org.apache.activemq.reader.BytesMessageUtil.bytesMessageReset;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesReadBoolean;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesReadByte;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesReadBytes;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesReadChar;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesReadDouble;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesReadFloat;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesReadInt;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesReadLong;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesReadShort;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesReadUTF;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesReadUnsignedByte;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesReadUnsignedShort;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesWriteBoolean;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesWriteByte;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesWriteBytes;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesWriteChar;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesWriteDouble;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesWriteFloat;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesWriteInt;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesWriteLong;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesWriteObject;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesWriteShort;
-import static org.apache.activemq.reader.BytesMessageUtil.bytesWriteUTF;
+import org.apache.activemq.artemis.core.message.impl.MessageImpl;
+import org.apache.activemq.artemis.core.message.impl.MessageInternal;
+
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesMessageReset;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesReadBoolean;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesReadByte;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesReadBytes;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesReadChar;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesReadDouble;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesReadFloat;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesReadInt;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesReadLong;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesReadShort;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesReadUTF;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesReadUnsignedByte;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesReadUnsignedShort;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesWriteBoolean;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesWriteByte;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesWriteBytes;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesWriteChar;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesWriteDouble;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesWriteFloat;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesWriteInt;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesWriteLong;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesWriteObject;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesWriteShort;
+import static org.apache.activemq.artemis.reader.BytesMessageUtil.bytesWriteUTF;
 
 public class ServerJMSBytesMessage extends ServerJMSMessage implements BytesMessage
 {

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSMapMessage.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSMapMessage.java b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSMapMessage.java
index a117c0f..11b5b13 100644
--- a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSMapMessage.java
+++ b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSMapMessage.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.core.protocol.proton.converter.jms;
+package org.apache.activemq.artemis.core.protocol.proton.converter.jms;
 
 import javax.jms.JMSException;
 import javax.jms.MapMessage;
@@ -24,14 +24,14 @@ import java.util.Enumeration;
 import java.util.HashSet;
 import java.util.Set;
 
-import org.apache.activemq.api.core.ActiveMQPropertyConversionException;
-import org.apache.activemq.api.core.Message;
-import org.apache.activemq.api.core.SimpleString;
-import org.apache.activemq.core.message.impl.MessageInternal;
-import org.apache.activemq.utils.TypedProperties;
+import org.apache.activemq.artemis.api.core.ActiveMQPropertyConversionException;
+import org.apache.activemq.artemis.api.core.Message;
+import org.apache.activemq.artemis.api.core.SimpleString;
+import org.apache.activemq.artemis.core.message.impl.MessageInternal;
+import org.apache.activemq.artemis.utils.TypedProperties;
 
-import static org.apache.activemq.reader.MapMessageUtil.readBodyMap;
-import static org.apache.activemq.reader.MapMessageUtil.writeBodyMap;
+import static org.apache.activemq.artemis.reader.MapMessageUtil.readBodyMap;
+import static org.apache.activemq.artemis.reader.MapMessageUtil.writeBodyMap;
 
 /**
  * ActiveMQ implementation of a JMS MapMessage.

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSMessage.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSMessage.java b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSMessage.java
index 7d38065..40c7621 100644
--- a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSMessage.java
+++ b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSMessage.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.core.protocol.proton.converter.jms;
+package org.apache.activemq.artemis.core.protocol.proton.converter.jms;
 
 import javax.jms.DeliveryMode;
 import javax.jms.Destination;
@@ -23,12 +23,12 @@ import javax.jms.Message;
 import java.util.Collections;
 import java.util.Enumeration;
 
-import org.apache.activemq.api.core.ActiveMQException;
-import org.apache.activemq.api.core.SimpleString;
-import org.apache.activemq.core.message.impl.MessageInternal;
-import org.apache.activemq.jms.client.ActiveMQDestination;
-import org.apache.activemq.jms.client.ActiveMQQueue;
-import org.apache.activemq.reader.MessageUtil;
+import org.apache.activemq.artemis.api.core.ActiveMQException;
+import org.apache.activemq.artemis.api.core.SimpleString;
+import org.apache.activemq.artemis.core.message.impl.MessageInternal;
+import org.apache.activemq.artemis.jms.client.ActiveMQDestination;
+import org.apache.activemq.artemis.jms.client.ActiveMQQueue;
+import org.apache.activemq.artemis.reader.MessageUtil;
 
 public class ServerJMSMessage implements Message
 {

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSStreamMessage.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSStreamMessage.java b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSStreamMessage.java
index 73d1b69..cf85ca3 100644
--- a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSStreamMessage.java
+++ b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSStreamMessage.java
@@ -14,31 +14,31 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.core.protocol.proton.converter.jms;
+package org.apache.activemq.artemis.core.protocol.proton.converter.jms;
 
 import javax.jms.JMSException;
 import javax.jms.MessageEOFException;
 import javax.jms.MessageFormatException;
 import javax.jms.StreamMessage;
 
-import org.apache.activemq.api.core.ActiveMQBuffer;
-import org.apache.activemq.api.core.Message;
-import org.apache.activemq.api.core.Pair;
-import org.apache.activemq.core.message.impl.MessageInternal;
-import org.apache.activemq.utils.DataConstants;
-
-import static org.apache.activemq.reader.MessageUtil.getBodyBuffer;
-import static org.apache.activemq.reader.StreamMessageUtil.streamReadBoolean;
-import static org.apache.activemq.reader.StreamMessageUtil.streamReadByte;
-import static org.apache.activemq.reader.StreamMessageUtil.streamReadBytes;
-import static org.apache.activemq.reader.StreamMessageUtil.streamReadChar;
-import static org.apache.activemq.reader.StreamMessageUtil.streamReadDouble;
-import static org.apache.activemq.reader.StreamMessageUtil.streamReadFloat;
-import static org.apache.activemq.reader.StreamMessageUtil.streamReadInteger;
-import static org.apache.activemq.reader.StreamMessageUtil.streamReadLong;
-import static org.apache.activemq.reader.StreamMessageUtil.streamReadObject;
-import static org.apache.activemq.reader.StreamMessageUtil.streamReadShort;
-import static org.apache.activemq.reader.StreamMessageUtil.streamReadString;
+import org.apache.activemq.artemis.api.core.ActiveMQBuffer;
+import org.apache.activemq.artemis.api.core.Message;
+import org.apache.activemq.artemis.api.core.Pair;
+import org.apache.activemq.artemis.core.message.impl.MessageInternal;
+import org.apache.activemq.artemis.utils.DataConstants;
+
+import static org.apache.activemq.artemis.reader.MessageUtil.getBodyBuffer;
+import static org.apache.activemq.artemis.reader.StreamMessageUtil.streamReadBoolean;
+import static org.apache.activemq.artemis.reader.StreamMessageUtil.streamReadByte;
+import static org.apache.activemq.artemis.reader.StreamMessageUtil.streamReadBytes;
+import static org.apache.activemq.artemis.reader.StreamMessageUtil.streamReadChar;
+import static org.apache.activemq.artemis.reader.StreamMessageUtil.streamReadDouble;
+import static org.apache.activemq.artemis.reader.StreamMessageUtil.streamReadFloat;
+import static org.apache.activemq.artemis.reader.StreamMessageUtil.streamReadInteger;
+import static org.apache.activemq.artemis.reader.StreamMessageUtil.streamReadLong;
+import static org.apache.activemq.artemis.reader.StreamMessageUtil.streamReadObject;
+import static org.apache.activemq.artemis.reader.StreamMessageUtil.streamReadShort;
+import static org.apache.activemq.artemis.reader.StreamMessageUtil.streamReadString;
 
 public final class ServerJMSStreamMessage extends ServerJMSMessage implements StreamMessage
 {

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSTextMessage.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSTextMessage.java b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSTextMessage.java
index c8796f9..05aa81a 100644
--- a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSTextMessage.java
+++ b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSTextMessage.java
@@ -14,17 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.core.protocol.proton.converter.jms;
+package org.apache.activemq.artemis.core.protocol.proton.converter.jms;
 
 import javax.jms.JMSException;
 import javax.jms.TextMessage;
 
-import org.apache.activemq.api.core.Message;
-import org.apache.activemq.api.core.SimpleString;
-import org.apache.activemq.core.message.impl.MessageInternal;
+import org.apache.activemq.artemis.api.core.Message;
+import org.apache.activemq.artemis.api.core.SimpleString;
+import org.apache.activemq.artemis.core.message.impl.MessageInternal;
 
-import static org.apache.activemq.reader.TextMessageUtil.readBodyText;
-import static org.apache.activemq.reader.TextMessageUtil.writeBodyText;
+import static org.apache.activemq.artemis.reader.TextMessageUtil.readBodyText;
+import static org.apache.activemq.artemis.reader.TextMessageUtil.writeBodyText;
 
 
 /**

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/package-info.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/package-info.java b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/package-info.java
index 00745f6..f4dcbc6 100644
--- a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/package-info.java
+++ b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/package-info.java
@@ -14,4 +14,4 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.core.protocol.proton.converter.jms;
\ No newline at end of file
+package org.apache.activemq.artemis.core.protocol.proton.converter.jms;
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/plug/ActiveMQProtonConnectionCallback.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/plug/ActiveMQProtonConnectionCallback.java b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/plug/ActiveMQProtonConnectionCallback.java
index 4d83dac..52bc316 100644
--- a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/plug/ActiveMQProtonConnectionCallback.java
+++ b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/plug/ActiveMQProtonConnectionCallback.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.core.protocol.proton.plug;
+package org.apache.activemq.artemis.core.protocol.proton.plug;
 
 import java.util.concurrent.Executor;
 import java.util.concurrent.TimeUnit;
@@ -22,12 +22,12 @@ import java.util.concurrent.TimeUnit;
 import io.netty.buffer.ByteBuf;
 import io.netty.channel.ChannelFuture;
 import io.netty.channel.ChannelFutureListener;
-import org.apache.activemq.core.buffers.impl.ChannelBufferWrapper;
-import org.apache.activemq.core.protocol.proton.ActiveMQProtonRemotingConnection;
-import org.apache.activemq.core.protocol.proton.ProtonProtocolManager;
-import org.apache.activemq.core.protocol.proton.sasl.ActiveMQPlainSASL;
-import org.apache.activemq.spi.core.remoting.Connection;
-import org.apache.activemq.utils.ReusableLatch;
+import org.apache.activemq.artemis.core.buffers.impl.ChannelBufferWrapper;
+import org.apache.activemq.artemis.core.protocol.proton.ActiveMQProtonRemotingConnection;
+import org.apache.activemq.artemis.core.protocol.proton.ProtonProtocolManager;
+import org.apache.activemq.artemis.core.protocol.proton.sasl.ActiveMQPlainSASL;
+import org.apache.activemq.artemis.spi.core.remoting.Connection;
+import org.apache.activemq.artemis.utils.ReusableLatch;
 import org.proton.plug.AMQPConnectionCallback;
 import org.proton.plug.AMQPConnectionContext;
 import org.proton.plug.AMQPSessionCallback;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/plug/ProtonSessionIntegrationCallback.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/plug/ProtonSessionIntegrationCallback.java b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/plug/ProtonSessionIntegrationCallback.java
index 6aedd25..9e60be4 100644
--- a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/plug/ProtonSessionIntegrationCallback.java
+++ b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/plug/ProtonSessionIntegrationCallback.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.core.protocol.proton.plug;
+package org.apache.activemq.artemis.core.protocol.proton.plug;
 
 
 import java.util.concurrent.Executor;
@@ -28,20 +28,20 @@ import org.apache.qpid.proton.engine.Link;
 import org.apache.qpid.proton.engine.Receiver;
 import org.apache.qpid.proton.jms.EncodedMessage;
 import org.apache.qpid.proton.message.ProtonJMessage;
-import org.apache.activemq.api.core.SimpleString;
-import org.apache.activemq.api.core.client.ActiveMQClient;
-import org.apache.activemq.core.journal.IOAsyncTask;
-import org.apache.activemq.core.protocol.proton.ProtonProtocolManager;
-import org.apache.activemq.core.server.QueueQueryResult;
-import org.apache.activemq.core.server.ServerConsumer;
-import org.apache.activemq.core.server.ServerMessage;
-import org.apache.activemq.core.server.ServerSession;
-import org.apache.activemq.spi.core.protocol.SessionCallback;
-import org.apache.activemq.spi.core.remoting.ReadyListener;
-import org.apache.activemq.utils.ByteUtil;
-import org.apache.activemq.utils.IDGenerator;
-import org.apache.activemq.utils.SimpleIDGenerator;
-import org.apache.activemq.utils.UUIDGenerator;
+import org.apache.activemq.artemis.api.core.SimpleString;
+import org.apache.activemq.artemis.api.core.client.ActiveMQClient;
+import org.apache.activemq.artemis.core.journal.IOAsyncTask;
+import org.apache.activemq.artemis.core.protocol.proton.ProtonProtocolManager;
+import org.apache.activemq.artemis.core.server.QueueQueryResult;
+import org.apache.activemq.artemis.core.server.ServerConsumer;
+import org.apache.activemq.artemis.core.server.ServerMessage;
+import org.apache.activemq.artemis.core.server.ServerSession;
+import org.apache.activemq.artemis.spi.core.protocol.SessionCallback;
+import org.apache.activemq.artemis.spi.core.remoting.ReadyListener;
+import org.apache.activemq.artemis.utils.ByteUtil;
+import org.apache.activemq.artemis.utils.IDGenerator;
+import org.apache.activemq.artemis.utils.SimpleIDGenerator;
+import org.apache.activemq.artemis.utils.UUIDGenerator;
 import org.proton.plug.AMQPConnectionContext;
 import org.proton.plug.AMQPSessionCallback;
 import org.proton.plug.AMQPSessionContext;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/plug/package-info.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/plug/package-info.java b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/plug/package-info.java
index e8b06df..455b5bb 100644
--- a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/plug/package-info.java
+++ b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/plug/package-info.java
@@ -14,4 +14,4 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.core.protocol.proton.plug;
\ No newline at end of file
+package org.apache.activemq.artemis.core.protocol.proton.plug;
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/sasl/ActiveMQPlainSASL.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/sasl/ActiveMQPlainSASL.java b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/sasl/ActiveMQPlainSASL.java
index 966ffb4..cb21ea0 100644
--- a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/sasl/ActiveMQPlainSASL.java
+++ b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/sasl/ActiveMQPlainSASL.java
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.core.protocol.proton.sasl;
+package org.apache.activemq.artemis.core.protocol.proton.sasl;
 
-import org.apache.activemq.core.security.SecurityStore;
-import org.apache.activemq.spi.core.security.ActiveMQSecurityManager;
+import org.apache.activemq.artemis.core.security.SecurityStore;
+import org.apache.activemq.artemis.spi.core.security.ActiveMQSecurityManager;
 import org.proton.plug.sasl.ServerSASLPlain;
 
 public class ActiveMQPlainSASL extends ServerSASLPlain

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-protocols/artemis-amqp-protocol/src/main/resources/META-INF/services/org.apache.activemq.artemis.spi.core.protocol.ProtocolManagerFactory
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-amqp-protocol/src/main/resources/META-INF/services/org.apache.activemq.artemis.spi.core.protocol.ProtocolManagerFactory b/artemis-protocols/artemis-amqp-protocol/src/main/resources/META-INF/services/org.apache.activemq.artemis.spi.core.protocol.ProtocolManagerFactory
new file mode 100644
index 0000000..2cd27f4
--- /dev/null
+++ b/artemis-protocols/artemis-amqp-protocol/src/main/resources/META-INF/services/org.apache.activemq.artemis.spi.core.protocol.ProtocolManagerFactory
@@ -0,0 +1 @@
+org.apache.activemq.artemis.core.protocol.proton.ProtonProtocolManagerFactory
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-protocols/artemis-amqp-protocol/src/main/resources/META-INF/services/org.apache.activemq.spi.core.protocol.ProtocolManagerFactory
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-amqp-protocol/src/main/resources/META-INF/services/org.apache.activemq.spi.core.protocol.ProtocolManagerFactory b/artemis-protocols/artemis-amqp-protocol/src/main/resources/META-INF/services/org.apache.activemq.spi.core.protocol.ProtocolManagerFactory
deleted file mode 100644
index 8f035c7..0000000
--- a/artemis-protocols/artemis-amqp-protocol/src/main/resources/META-INF/services/org.apache.activemq.spi.core.protocol.ProtocolManagerFactory
+++ /dev/null
@@ -1 +0,0 @@
-org.apache.activemq.core.protocol.proton.ProtonProtocolManagerFactory
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-protocols/artemis-amqp-protocol/src/test/java/org/apache/activemq/artemis/core/protocol/proton/TestConversions.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-amqp-protocol/src/test/java/org/apache/activemq/artemis/core/protocol/proton/TestConversions.java b/artemis-protocols/artemis-amqp-protocol/src/test/java/org/apache/activemq/artemis/core/protocol/proton/TestConversions.java
index 9195b53..830b38b 100644
--- a/artemis-protocols/artemis-amqp-protocol/src/test/java/org/apache/activemq/artemis/core/protocol/proton/TestConversions.java
+++ b/artemis-protocols/artemis-amqp-protocol/src/test/java/org/apache/activemq/artemis/core/protocol/proton/TestConversions.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.core.protocol.proton;
+package org.apache.activemq.artemis.core.protocol.proton;
 
 import java.nio.ByteBuffer;
 import java.util.HashMap;
@@ -24,7 +24,7 @@ import java.util.Map;
 
 import io.netty.buffer.ByteBuf;
 import io.netty.buffer.PooledByteBufAllocator;
-import org.apache.activemq.api.core.ActiveMQBuffer;
+import org.apache.activemq.artemis.api.core.ActiveMQBuffer;
 import org.apache.qpid.proton.amqp.Binary;
 import org.apache.qpid.proton.amqp.messaging.AmqpSequence;
 import org.apache.qpid.proton.amqp.messaging.AmqpValue;
@@ -34,16 +34,16 @@ import org.apache.qpid.proton.jms.EncodedMessage;
 import org.apache.qpid.proton.message.Message;
 import org.apache.qpid.proton.message.ProtonJMessage;
 import org.apache.qpid.proton.message.impl.MessageImpl;
-import org.apache.activemq.api.core.SimpleString;
-import org.apache.activemq.core.journal.EncodingSupport;
-import org.apache.activemq.core.protocol.proton.converter.ProtonMessageConverter;
-import org.apache.activemq.core.protocol.proton.converter.jms.ServerJMSBytesMessage;
-import org.apache.activemq.core.protocol.proton.converter.jms.ServerJMSMapMessage;
-import org.apache.activemq.core.protocol.proton.converter.jms.ServerJMSMessage;
-import org.apache.activemq.core.protocol.proton.converter.jms.ServerJMSStreamMessage;
-import org.apache.activemq.core.protocol.proton.converter.jms.ServerJMSTextMessage;
-import org.apache.activemq.core.server.ServerMessage;
-import org.apache.activemq.utils.SimpleIDGenerator;
+import org.apache.activemq.artemis.api.core.SimpleString;
+import org.apache.activemq.artemis.core.journal.EncodingSupport;
+import org.apache.activemq.artemis.core.protocol.proton.converter.ProtonMessageConverter;
+import org.apache.activemq.artemis.core.protocol.proton.converter.jms.ServerJMSBytesMessage;
+import org.apache.activemq.artemis.core.protocol.proton.converter.jms.ServerJMSMapMessage;
+import org.apache.activemq.artemis.core.protocol.proton.converter.jms.ServerJMSMessage;
+import org.apache.activemq.artemis.core.protocol.proton.converter.jms.ServerJMSStreamMessage;
+import org.apache.activemq.artemis.core.protocol.proton.converter.jms.ServerJMSTextMessage;
+import org.apache.activemq.artemis.core.server.ServerMessage;
+import org.apache.activemq.artemis.utils.SimpleIDGenerator;
 import org.junit.Assert;
 import org.junit.Test;
 import org.proton.plug.util.NettyWritable;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-protocols/artemis-openwire-protocol/pom.xml
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-openwire-protocol/pom.xml b/artemis-protocols/artemis-openwire-protocol/pom.xml
index b81c87f..4c60e90 100644
--- a/artemis-protocols/artemis-openwire-protocol/pom.xml
+++ b/artemis-protocols/artemis-openwire-protocol/pom.xml
@@ -16,17 +16,16 @@
 -->
 <project xmlns="http://maven.apache.org/POM/4.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/xsd/maven-4.0.0.xsd">
    <parent>
-      <artifactId>activemq-protocols</artifactId>
+      <artifactId>artemis-protocols</artifactId>
       <groupId>org.apache.activemq</groupId>
-      <version>10.0.0-SNAPSHOT</version>
+      <version>1.0.0-SNAPSHOT</version>
    </parent>
    <modelVersion>4.0.0</modelVersion>
 
-   <artifactId>activemq-openwire-protocol</artifactId>
-   <name>ActiveMQ Artemis OpenWire Protocol</name>
+   <artifactId>artemis-openwire-protocol</artifactId>
 
    <properties>
-      <activemq.basedir>${project.parent.parent.basedir}</activemq.basedir>
+      <activemq.basedir>${project.basedir}/../..</activemq.basedir>
    </properties>
 
    <dependencies>
@@ -54,12 +53,12 @@
       </dependency>
       <dependency>
          <groupId>org.apache.activemq</groupId>
-         <artifactId>activemq-server</artifactId>
+         <artifactId>artemis-server</artifactId>
          <version>${project.version}</version>
       </dependency>
       <dependency>
          <groupId>org.apache.activemq</groupId>
-         <artifactId>activemq-jms-client</artifactId>
+         <artifactId>artemis-jms-client</artifactId>
          <version>${project.version}</version>
       </dependency>
    </dependencies>

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/AMQConnectorImpl.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/AMQConnectorImpl.java b/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/AMQConnectorImpl.java
index 98eb096..e6ccd0e 100644
--- a/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/AMQConnectorImpl.java
+++ b/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/AMQConnectorImpl.java
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.core.protocol.openwire;
+package org.apache.activemq.artemis.core.protocol.openwire;
 
 import org.apache.activemq.command.BrokerInfo;
 import org.apache.activemq.command.ConnectionControl;
-import org.apache.activemq.core.protocol.openwire.amq.AMQConnector;
-import org.apache.activemq.core.protocol.openwire.amq.AMQConnectorStatistics;
-import org.apache.activemq.spi.core.remoting.Acceptor;
+import org.apache.activemq.artemis.core.protocol.openwire.amq.AMQConnector;
+import org.apache.activemq.artemis.core.protocol.openwire.amq.AMQConnectorStatistics;
+import org.apache.activemq.artemis.spi.core.remoting.Acceptor;
 
 public class AMQConnectorImpl implements AMQConnector
 {

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/AMQTransactionImpl.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/AMQTransactionImpl.java b/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/AMQTransactionImpl.java
index 393bd9d..c992487 100644
--- a/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/AMQTransactionImpl.java
+++ b/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/AMQTransactionImpl.java
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.core.protocol.openwire;
+package org.apache.activemq.artemis.core.protocol.openwire;
 
-import org.apache.activemq.core.persistence.StorageManager;
-import org.apache.activemq.core.server.Queue;
-import org.apache.activemq.core.server.impl.RefsOperation;
-import org.apache.activemq.core.transaction.Transaction;
-import org.apache.activemq.core.transaction.impl.TransactionImpl;
+import org.apache.activemq.artemis.core.persistence.StorageManager;
+import org.apache.activemq.artemis.core.server.Queue;
+import org.apache.activemq.artemis.core.server.impl.RefsOperation;
+import org.apache.activemq.artemis.core.transaction.Transaction;
+import org.apache.activemq.artemis.core.transaction.impl.TransactionImpl;
 
 import javax.transaction.xa.Xid;
 

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/BrokerState.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/BrokerState.java b/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/BrokerState.java
index 33a9dc5..44ab3a7 100644
--- a/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/BrokerState.java
+++ b/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/BrokerState.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.core.protocol.openwire;
+package org.apache.activemq.artemis.core.protocol.openwire;
 
 /**
  * The class holds related states of an activemq broker.

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/DataInputWrapper.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/DataInputWrapper.java b/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/DataInputWrapper.java
index c3f341d..d9fd6d7 100644
--- a/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/DataInputWrapper.java
+++ b/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/DataInputWrapper.java
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.core.protocol.openwire;
+package org.apache.activemq.artemis.core.protocol.openwire;
 
 import java.io.DataInput;
 import java.io.IOException;
 import java.nio.ByteBuffer;
 
-import org.apache.activemq.api.core.ActiveMQBuffer;
-import org.apache.activemq.utils.UTF8Util;
-import org.apache.activemq.utils.UTF8Util.StringUtilBuffer;
+import org.apache.activemq.artemis.api.core.ActiveMQBuffer;
+import org.apache.activemq.artemis.utils.UTF8Util;
+import org.apache.activemq.artemis.utils.UTF8Util.StringUtilBuffer;
 
 public class DataInputWrapper implements DataInput
 {

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/NotEnoughBytesException.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/NotEnoughBytesException.java b/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/NotEnoughBytesException.java
index c01fdff..29813d0 100644
--- a/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/NotEnoughBytesException.java
+++ b/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/NotEnoughBytesException.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.core.protocol.openwire;
+package org.apache.activemq.artemis.core.protocol.openwire;
 
 import java.io.IOException;
 

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/OpenWireConnection.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/OpenWireConnection.java b/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/OpenWireConnection.java
index b096381..b7258c3 100644
--- a/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/OpenWireConnection.java
+++ b/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/OpenWireConnection.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.core.protocol.openwire;
+package org.apache.activemq.artemis.core.protocol.openwire;
 
 import javax.jms.InvalidDestinationException;
 import javax.jms.JMSSecurityException;
@@ -34,12 +34,12 @@ import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.locks.ReentrantReadWriteLock;
 
-import org.apache.activemq.api.core.ActiveMQBuffer;
-import org.apache.activemq.api.core.ActiveMQBuffers;
-import org.apache.activemq.api.core.ActiveMQException;
-import org.apache.activemq.api.core.ActiveMQNonExistentQueueException;
-import org.apache.activemq.api.core.ActiveMQSecurityException;
-import org.apache.activemq.api.core.SimpleString;
+import org.apache.activemq.artemis.api.core.ActiveMQBuffer;
+import org.apache.activemq.artemis.api.core.ActiveMQBuffers;
+import org.apache.activemq.artemis.api.core.ActiveMQException;
+import org.apache.activemq.artemis.api.core.ActiveMQNonExistentQueueException;
+import org.apache.activemq.artemis.api.core.ActiveMQSecurityException;
+import org.apache.activemq.artemis.api.core.SimpleString;
 import org.apache.activemq.command.ActiveMQDestination;
 import org.apache.activemq.command.ActiveMQMessage;
 import org.apache.activemq.command.BrokerInfo;
@@ -74,24 +74,24 @@ import org.apache.activemq.command.ShutdownInfo;
 import org.apache.activemq.command.TransactionId;
 import org.apache.activemq.command.TransactionInfo;
 import org.apache.activemq.command.WireFormatInfo;
-import org.apache.activemq.core.protocol.openwire.amq.AMQBrokerStoppedException;
-import org.apache.activemq.core.protocol.openwire.amq.AMQConnectionContext;
-import org.apache.activemq.core.protocol.openwire.amq.AMQConsumerBrokerExchange;
-import org.apache.activemq.core.protocol.openwire.amq.AMQMapTransportConnectionStateRegister;
-import org.apache.activemq.core.protocol.openwire.amq.AMQMessageAuthorizationPolicy;
-import org.apache.activemq.core.protocol.openwire.amq.AMQProducerBrokerExchange;
-import org.apache.activemq.core.protocol.openwire.amq.AMQSession;
-import org.apache.activemq.core.protocol.openwire.amq.AMQSingleTransportConnectionStateRegister;
-import org.apache.activemq.core.protocol.openwire.amq.AMQTransaction;
-import org.apache.activemq.core.protocol.openwire.amq.AMQTransportConnectionState;
-import org.apache.activemq.core.protocol.openwire.amq.AMQTransportConnectionStateRegister;
-import org.apache.activemq.core.remoting.CloseListener;
-import org.apache.activemq.core.remoting.FailureListener;
-import org.apache.activemq.core.server.ActiveMQServerLogger;
+import org.apache.activemq.artemis.core.protocol.openwire.amq.AMQBrokerStoppedException;
+import org.apache.activemq.artemis.core.protocol.openwire.amq.AMQConnectionContext;
+import org.apache.activemq.artemis.core.protocol.openwire.amq.AMQConsumerBrokerExchange;
+import org.apache.activemq.artemis.core.protocol.openwire.amq.AMQMapTransportConnectionStateRegister;
+import org.apache.activemq.artemis.core.protocol.openwire.amq.AMQMessageAuthorizationPolicy;
+import org.apache.activemq.artemis.core.protocol.openwire.amq.AMQProducerBrokerExchange;
+import org.apache.activemq.artemis.core.protocol.openwire.amq.AMQSession;
+import org.apache.activemq.artemis.core.protocol.openwire.amq.AMQSingleTransportConnectionStateRegister;
+import org.apache.activemq.artemis.core.protocol.openwire.amq.AMQTransaction;
+import org.apache.activemq.artemis.core.protocol.openwire.amq.AMQTransportConnectionState;
+import org.apache.activemq.artemis.core.protocol.openwire.amq.AMQTransportConnectionStateRegister;
+import org.apache.activemq.artemis.core.remoting.CloseListener;
+import org.apache.activemq.artemis.core.remoting.FailureListener;
+import org.apache.activemq.artemis.core.server.ActiveMQServerLogger;
 import org.apache.activemq.openwire.OpenWireFormat;
-import org.apache.activemq.spi.core.protocol.RemotingConnection;
-import org.apache.activemq.spi.core.remoting.Acceptor;
-import org.apache.activemq.spi.core.remoting.Connection;
+import org.apache.activemq.artemis.spi.core.protocol.RemotingConnection;
+import org.apache.activemq.artemis.spi.core.remoting.Acceptor;
+import org.apache.activemq.artemis.spi.core.remoting.Connection;
 import org.apache.activemq.state.CommandVisitor;
 import org.apache.activemq.state.ConnectionState;
 import org.apache.activemq.state.ConsumerState;
@@ -101,7 +101,7 @@ import org.apache.activemq.thread.TaskRunner;
 import org.apache.activemq.thread.TaskRunnerFactory;
 import org.apache.activemq.transport.TransmitCallback;
 import org.apache.activemq.util.ByteSequence;
-import org.apache.activemq.utils.ConcurrentHashSet;
+import org.apache.activemq.artemis.utils.ConcurrentHashSet;
 import org.apache.activemq.wireformat.WireFormat;
 
 /**
diff --git a/artemis-native/src/main/java/org/apache/activemq/artemis/core/libaio/Native.java b/artemis-native/src/main/java/org/apache/activemq/artemis/core/libaio/Native.java
index bce218a..82f4188 100644
--- a/artemis-native/src/main/java/org/apache/activemq/artemis/core/libaio/Native.java
+++ b/artemis-native/src/main/java/org/apache/activemq/artemis/core/libaio/Native.java
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.core.libaio;
+package org.apache.activemq.artemis.core.libaio;
 
 import java.nio.ByteBuffer;
 
-import org.apache.activemq.api.core.ActiveMQException;
+import org.apache.activemq.artemis.api.core.ActiveMQException;
 
 public class Native
 {
@@ -53,7 +53,7 @@ public class Native
    public static native void writeInternal(ByteBuffer handle, long positionToWrite, long size, ByteBuffer bytes) throws ActiveMQException;
 
    /**
     *This is using org.apache.activemq.core.asyncio.AIOCallback
      */
    public static native void read(Object thisObject, ByteBuffer handle, long position, long size, ByteBuffer buffer, Object aioPackageCallback) throws ActiveMQException;
 

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-protocols/artemis-amqp-protocol/pom.xml
----------------------------------------------------------------------
@@ -53,7 +53,7 @@ public class Native
 
    /**
-    *This is using org.apache.activemq.core.asyncio.AIOCallback
+    *This is using org.apache.activemq.artemis.core.asyncio.AIOCallback
      */
    public static native void read(Object thisObject, ByteBuffer handle, long position, long size, ByteBuffer buffer, Object aioPackageCallback) throws ActiveMQException;